==> cdktf-cdktf-provider-azuread-0.4.17.tar.gz: package/lib/claims-mapping-policy.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ClaimsMappingPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * A string collection containing a JSON string that defines the rules and settings for this policy
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/claims_mapping_policy#definition ClaimsMappingPolicy#definition}
    */
    readonly definition: string[];
    /**
    * Display name for this policy
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/claims_mapping_policy#display_name ClaimsMappingPolicy#display_name}
    */
    readonly displayName: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azuread/r/claims_mapping_policy azuread_claims_mapping_policy}
*/
export declare class ClaimsMappingPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "azuread_claims_mapping_policy";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azuread/r/claims_mapping_policy azuread_claims_mapping_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ClaimsMappingPolicyConfig
    */
    constructor(scope: Construct, id: string, config: ClaimsMappingPolicyConfig);
    private _definition?;
    get definition(): string[];
    set definition(value: string[]);
    get definitionInput(): string[] | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    get id(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-azuread-2.0.41.tar.gz: package/lib/claims-mapping-policy.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ClaimsMappingPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * A string collection containing a JSON string that defines the rules and settings for this policy
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/claims_mapping_policy#definition ClaimsMappingPolicy#definition}
    */
    readonly definition: string[];
    /**
    * Display name for this policy
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/claims_mapping_policy#display_name ClaimsMappingPolicy#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/claims_mapping_policy#id ClaimsMappingPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azuread/r/claims_mapping_policy azuread_claims_mapping_policy}
*/
export declare class ClaimsMappingPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "azuread_claims_mapping_policy";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azuread/r/claims_mapping_policy azuread_claims_mapping_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ClaimsMappingPolicyConfig
    */
    constructor(scope: Construct, id: string, config: ClaimsMappingPolicyConfig);
    private _definition?;
    get definition(): string[];
    set definition(value: string[]);
    get definitionInput(): string[] | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
